@@ -15,6 +15,8 @@ use base 'Log::Log4perl::Layout::PatternLayout';
 
 use Carp;
 use Carp::Parse::Redact;
+use Data::Validate::Type;
+use Try::Tiny;
 
 
 =head1 NAME
@@ -35,20 +37,22 @@ can be PCI-compliant.
 
 =head1 VERSION
 
-Version 1.1.1
+Version 1.2.0
 
 =cut
 
-our $VERSION = '1.1.1';
+our $VERSION = '1.2.0';
 
 our $SENSITIVE_ARGUMENT_NAMES = undef;
 our $SENSITIVE_REGEXP_PATTERNS = undef;
-
+our $MESSAGE_REDACTION_CALLBACK = undef;
 
 =head1 SYNOPSIS
 
 	use Log::Log4perl::Layout::PatternLayout::Redact;
 
+=head2 Redacting stack traces
+
 Here's an example of log4perl configuration that outputs a redacted trace
 (use I<%E> instead of I<%T>) :
 
@@ -87,9 +91,39 @@ will be replaced with '[redacted]'.
 Be sure to do the localizations of the package variables after you have
 initialized your logger.
 
+=head2 Redacting messages
+
+Here's an example of log4perl configuration that outputs a redacted message
+(use I<%e> instead of I<%m>) :
+
+	log4perl.logger = WARN, logfile
+	log4perl.appender.logfile                          = Log::Log4perl::Appender::File
+	log4perl.appender.logfile.filename                 = $file_name
+	log4perl.appender.logfile.layout                   = Log::Log4perl::Layout::PatternLayout::Redact
+	log4perl.appender.logfile.layout.ConversionPattern = %d %p: (%X{host}) %P %F:%L %M - %e
+	log4perl.appender.logfile.recreate                 = 1
+	log4perl.appender.logfile.mode                     = append
+
+To redact the message, you will need to write your own redaction subroutine as
+follows:
+
+	local $Log::Log4perl::Layout::PatternLayout::Redact::MESSAGE_REDACTION_CALLBACK = sub
+	{
+		my ( $message ) = @_;
+		
+		# Do replacements on the messages to redact sensitive information.
+		$message =~ s/(password=")[^"]+(")/$1\[redacted\]$2/g;
+		
+		return $message;
+	};
+
+Be sure to do the localizations of the package variable after you have
+initialized your logger.
+
 =cut
 
 # Add '%E' to the list of options available for the Log4perl layout.
+# This offers a redacted stack trace.
 Log::Log4perl::Layout::PatternLayout::add_global_cspec(
 	'E',
 	sub
@@ -128,6 +162,36 @@ Log::Log4perl::Layout::PatternLayout::add_global_cspec(
 	}
 );
 
+# Add '%e' to the list of options available for the Log4perl layout.
+# This offers a redacted message.
+Log::Log4perl::Layout::PatternLayout::add_global_cspec(
+	'e',
+	sub
+	{
+		my ( $self, $message ) = @_;
+		
+		return $message
+			if !defined( $MESSAGE_REDACTION_CALLBACK );
+		
+		my $redacted_message;
+		try
+		{
+			Carp::croak('the message redaction callback is not a valid code reference')
+				if !Data::Validate::Type::is_coderef( $MESSAGE_REDACTION_CALLBACK );
+			
+			$redacted_message = $MESSAGE_REDACTION_CALLBACK->( $message );
+		}
+		catch
+		{
+			my $error = $_;
+			Carp::carp("Failed to redact message: $error");
+			return $message;
+		};
+		
+		return $redacted_message;
+	}
+);
+
 
 =head1 AUTHOR
 
